@@ -26,12 +26,17 @@ class ContextMenu(object):
     def __init__(self, document, document_view):
         self.document = document
         self.document_view = document_view
+
         self.scbar_view = context_menu_view.ContextMenuView(document)
         stack = document_view.shortcuts_bar_bottom.more_actions_popover.get_child()
         stack.add_named(self.scbar_view, 'main')
         self.controller = context_menu_controller.ContextMenuController(self, self.scbar_view)
         self.presenter = context_menu_presenter.ContextMenuPresenter(self, self.scbar_view)
 
+        self.can_sync = False
+        self.forward_sync_manager = ServiceLocator.get_forward_sync_manager()
+        self.forward_sync_manager.register_observer(self)
+
         self.font_manager = ServiceLocator.get_font_manager()
         self.font_manager.register_observer(self)
 
@@ -39,8 +44,9 @@ class ContextMenu(object):
 
     def change_notification(self, change_code, notifying_object, parameter):
 
-        if change_code == 'can_sync_changed':
-            self.presenter.on_can_sync_changed(parameter)
+        if change_code == 'update_sync_state':
+            self.can_sync = self.forward_sync_manager.can_sync
+            self.presenter.on_can_sync_changed(self.can_sync)
             
         if change_code == 'font_string_changed':
             zoom_level = self.font_manager.get_zoom_level()
@@ -80,7 +86,7 @@ class ContextMenu(object):
         return True
 
     def on_show_in_preview(self, widget=None):
-        self.document.forward_sync()
+        self.forward_sync_manager.forward_sync(self.document)
 
     def on_toggle_comment(self, menu_item):
         self.document.comment_uncomment()
